/**
 * The result of a comparison between two ordered values.
 */
export declare enum Comparison {
    before = -1,
    equal = 0,
    after = 1,
    undefined = NaN
}
/**
 * The type of a function that compares two values of type T.
 */
export declare type Comparator<T> = (a: T, b: T) => Comparison;
/**
 * A general purpose comparator for comparing primitive values.
 */
export declare const compare: Comparator<string> & Comparator<number> & Comparator<boolean>;
/**
 * Returns a new comparator that gives opposite results to the provided
 * comparator.
 */
export declare function reverse<T>(comparator: Comparator<T>): Comparator<T>;
